@@ -27,9 +27,22 @@ pub enum RinexTypeError {
 }
 
 impl Default for RinexType {
+    /// Builds a default `RinexType`
     fn default() -> RinexType { RinexType::ObservationData }
 }
 
+impl RinexType {
+    /// Converts `Self` to string
+    pub fn to_string(&self) -> &str {
+        match *self {
+            RinexType::ObservationData => "ObservationData",
+            RinexType::NavigationMessage => "NavigationMessage",
+            RinexType::MeteorologicalData => "MeteorologicalData",
+            RinexType::ClockData => "ClockData",
+        }
+    }
+}
+
 impl std::str::FromStr for RinexType {
     type Err = RinexTypeError;
     fn from_str (s: &str) -> Result<Self, Self::Err> {
@@ -267,7 +280,6 @@ pub struct Header {
     leap: Option<u32>, // leap seconds
     coords: Option<rust_3d::Point3D>, // station approx. coords
     wavelengths: Option<(u32,u32)>, // L1/L2 wavelengths
-    nb_observations: u64,
     sampling_interval: Option<f32>, // sampling
     epochs: (Option<GnssTime>, Option<GnssTime>), // first , last observations
     // true if epochs & data compensate for local clock drift 
@@ -319,7 +331,6 @@ impl Default for Header {
             leap: None,
             rcvr_clock_offset_applied: None,
             wavelengths: None,
-            nb_observations: 0,
             sampling_interval: None,
             epochs: (None, None),
             gps_utc_delta: None,
@@ -372,10 +383,20 @@ impl std::str::FromStr for Header {
 
         // line1 {} {} {} // label [VERSION/TYPE/GNSS] 
         let (version_str, remainder) = line.split_at(20);
-        let (rinex_type, remainder) = remainder.trim().split_at(20);
-        let (constellation, remainder) = remainder.trim().split_at(20);
-        println!("RINEX | VERSION \"{}\" | TYPE \"{}\" | OTHER \"{}\"", version_str, rinex_type, constellation);
+        let (type_str, remainder) = remainder.trim().split_at(20);
+        let (constellation_str, remainder) = remainder.trim().split_at(20);
+
+        let rinex_type = RinexType::from_str(type_str.trim())?;
+        let mut constellation: constellation::Constellation;
         
+        if type_str.trim().contains("GLONASS") {
+            // special case, sometimes GLONASS NAV
+            // drops the constellation field cause it's implied
+            constellation = constellation::Constellation::Glonass
+        } else {
+            constellation = constellation::Constellation::from_str(constellation_str.trim())?
+        }
+
         let version = version::Version::from_str(version_str.trim())?;
         if !version.is_supported() {
             return Err(HeaderError::VersionNotSupported(String::from(version_str)))
@@ -458,8 +479,8 @@ impl std::str::FromStr for Header {
         // indentifiers
         let mut station    = String::from("Unknown");
         let mut station_id = String::from("Unknown");
-        let mut observer   = String::from("Unknwon");
-        let mut agency     = String::from("Unknwown");
+        let mut observer   = String::from("Unknown");
+        let mut agency     = String::from("Unknown");
         // hardware
         let mut ant        : Option<Antenna> = None;
         let mut ant_coords : Option<rust_3d::Point3D> = None;
@@ -652,8 +673,8 @@ impl std::str::FromStr for Header {
         Ok(Header{
             version: version,
             crinex: crinex_infos, 
-            rinex_type: RinexType::from_str(rinex_type.trim())?,
-            constellation: constellation::Constellation::from_str(constellation.trim())?, 
+            rinex_type,
+            constellation,
             program: String::from(pgm.trim()),
             run_by: run_by,
             station: station,
@@ -666,7 +687,6 @@ impl std::str::FromStr for Header {
             rcvr_clock_offset_applied: rcvr_clock_offset_applied,
             coords: coords,
             wavelengths: None,
-            nb_observations: 0,
             sampling_interval: sampling_interval,
             epochs: epochs,
             gps_utc_delta: None,
