@@ -7,6 +7,7 @@ use thiserror::Error;
 use std::str::FromStr;
 use scan_fmt::scan_fmt;
 
+mod keys;
 mod header;
 mod record;
 mod version;
@@ -64,9 +65,10 @@ pub fn new_record_block (line: &str,
                         Some(c) => known_sv_identifiers.contains(&c), 
                         _ => false
                             //TODO
-                            // for some file we end but with "\nxxx"
-                            // as the very first item,
-                            // current code will drop first payload item
+                            // <o 
+                            //   for some files we end up with "\n xxxx" as first frame items 
+                            // current code will discard first payload item in such scenario
+                            // => need to cleanup (split(head,body) method)
                     }
                 }
             }
@@ -86,8 +88,7 @@ impl Rinex {
         }
     }
 
-    /// splits rinex file into two
-    /// (header, body) as strings
+    /// splits rinex file into two (header, body) contents
     fn split_rinex_content (fp: &std::path::Path) -> Result<(String, String), RinexError> {
         let content: String = std::fs::read_to_string(fp)
             .unwrap()
@@ -101,6 +102,11 @@ impl Rinex {
         Ok((String::from(header),String::from(body)))
     }
 
+    /// Returns `Rinex` length, ie.,
+    ///   nb of observations for `RinexType::ObservationData`   
+    ///   nb of ephemerides  for `RinexType::NavigationMessage`   
+    pub fn len (&self) -> usize { self.records.len() }
+    
     /// Builds a `Rinex` from given file.
     /// Input file must respect the whitespace specifications
     /// for the entire header section.   
@@ -116,12 +122,17 @@ impl Rinex {
         let (header, body) = Rinex::split_rinex_content(fp)?;
         let header = header::Header::from_str(&header)?;
 
+        // helpful information
         let rinex_type = header.get_rinex_type();
         let version = header.get_rinex_version();
         let version_major = version.get_major(); 
         let version_minor = version.get_minor(); 
         let constellation = header.get_constellation();
 
+        // build key listing for this context
+        let keys = keys::KeyBank::new(&version, &rinex_type, &constellation)
+            .unwrap();
+
         let mut body = body.lines();
         let mut line = body.next()
             .unwrap(); // ''END OF HEADER'' /BLANK
@@ -145,7 +156,7 @@ impl Rinex {
                 let record: Option<RinexRecord> = match rinex_type {
                     header::RinexType::NavigationMessage => {
                         if let Ok(record) = 
-                            navigation::NavigationRecord::from_string(&version, &constellation, &block) {
+                            navigation::NavigationRecord::from_string(version, constellation, &keys, &block) {
                                 Some(RinexRecord::RinexNavRecord(record))
                         } else {
                             None
@@ -199,8 +210,7 @@ impl Rinex {
 mod test {
     use super::*;
     #[test]
-    /// Test `Rinex` constructor
-    /// against all valid data resources
+    /// Tests `Rinex` constructor against all known test resources
     fn test_rinex_constructor() {
         // open test resources
         let test_resources = std::path::PathBuf::from(
