@@ -51,6 +51,8 @@ impl std::str::FromStr for Version {
 }
 
 impl Version {
+    /// Builds a new `Version` object
+    fn new (major: u8, minor: u8) -> Version { Version { major, minor }}
     /// Returns version major #
     pub fn get_major (&self) -> u8 { self.major }
     /// Returns version minor #
@@ -60,8 +62,10 @@ impl Version {
     pub fn is_supported (&self) -> bool {
         if self.major < SUPPORTED_VERSION.major {
             true
-        } else {
+        } else if self.major == SUPPORTED_VERSION.major {
             self.minor <= SUPPORTED_VERSION.minor
+        } else {
+            false
         }
     }
 }
@@ -74,10 +78,16 @@ mod test {
         assert_eq!(version.get_major(), 1);
         assert_eq!(version.get_minor(), 1);
     }
+    #[test]
     fn test_version_support() {
         let version = Version::default();
         assert_eq!(version.is_supported(), true);
         let version = SUPPORTED_VERSION; 
         assert_eq!(version.is_supported(), true);
     }
+    #[test]
+    fn test_version_non_support() {
+        let version = Version::new(5, 0);
+        assert_eq!(version.is_supported(), false);
+    }
 }
